<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LockScreen</name>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="202"/>
        <source>Password</source>
        <translation>كلمة المرور</translation>
    </message>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="225"/>
        <source>Unlock</source>
        <translation>إلغاء القُفْل</translation>
    </message>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="274"/>
        <source>Please enter your password</source>
        <translation>يُرجى إدخال كلمة المرور</translation>
    </message>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="284"/>
        <source>Unlocking failed</source>
        <translation>فَشِل إلغاء القُفْل</translation>
    </message>
</context>
</TS>
